@@ -14,14 +14,23 @@ doit wget -O $rdf~ http://www.kawa.net/rss/index-e.rdf
 diff $rdf $rdf~ > /dev/null || doit /bin/mv -f $rdf~ $rdf
 /bin/rm -f $rdf~
 
-egrep -v '^t/.*\.t$' MANIFEST > MANIFEST~
+[ -f Makefile ] && doit make clean
+[ -f META.yml ] || doit touch META.yml
+
+egrep -v '^(lib/.*\.pm|t/.*\.t)$' MANIFEST > MANIFEST~
+ls Makefile.PL README Changes MANIFEST META.yml COPYING >> MANIFEST~ 2> /dev/null
+find lib -type f -name '*.pm' >> MANIFEST~
 ls t/*.t >> MANIFEST~
+sort MANIFEST~ | uniq > MANIFEST~~
+/bin/mv -f MANIFEST~~ MANIFEST~
 diff MANIFEST MANIFEST~ > /dev/null || doit /bin/mv -f MANIFEST~ MANIFEST
 /bin/rm -f MANIFEST~
 
-[ -f Makefile ] && doit make clean
 doit perl Makefile.PL
-doit make
+doit make metafile
+newmeta=`ls -t */META.yml | head -1`
+diff META.yml $newmeta > /dev/null || doit /bin/cp -f $newmeta META.yml
+
 doit make disttest
 
 main=`grep 'lib/.*pm$' < MANIFEST | head -1`
